<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="45"/>
        <source>&amp;About</source>
        <translation>&amp;A proposito di</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="48"/>
        <source>Main developers</source>
        <translation>Sviluppatori principali</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="62"/>
        <source>A&amp;uthors</source>
        <translation>A&amp;utori</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="66"/>
        <source>Translation</source>
        <translation>Traduzione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="67"/>
        <source>Czech</source>
        <translation>Ceco</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="68"/>
        <source>Slovenian</source>
        <translation>Sloveno</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="69"/>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="77"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="78"/>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="79"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="80"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="81"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="82"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="83"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="85"/>
        <source>Logo</source>
        <translation>Logo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="87"/>
        <source>Coordinating</source>
        <translation>Coordinamento</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="91"/>
        <source>Testing</source>
        <translation>Prova</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="103"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;Ringraziamenti</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="108"/>
        <source>&amp;Licence Agreement</source>
        <translation>&amp;Licenza</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="110"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="123"/>
        <source>About</source>
        <translation>A proposito di</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="40"/>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation>Questo è il programma Stopmotion per creare animazioni in stop motion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="70"/>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="72"/>
        <source>Portuguese</source>
        <translation>Portoghese</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="74"/>
        <source>Spanish</source>
        <translation>Spagnolo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="75"/>
        <source>Swedish</source>
        <translation>Svedese</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="52"/>
        <source>Contributors</source>
        <translation>Contribuenti allo sviluppo</translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="64"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="357"/>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation>Di seguito puoi selezionare quale dispositivo Stopmotion dovrebbe usare per acquisire le immagini e per mostrare il video.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="66"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="359"/>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation>Puoi selezionare l&apos;autorivelamento del dispositivo di seguito o aggiungere da solo un dispositivo. Non è raccomandato usare dispositivi che non siano stati trovati automaticamente, ma sei libero di farlo se sei un utente esperto.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="69"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="362"/>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation>Il dispositivo selezionato è riconosciuto come &lt;b&gt;$VIDEODEVICE&lt;/b&gt; sotto Video Import.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="89"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="369"/>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="93"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="370"/>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="96"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="371"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modificare</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="100"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="374"/>
        <source>Video device settings</source>
        <translation>Preferenze del dispositivo Video</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="109"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="375"/>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation>Dispositivo Video ($VIDEODEVICE):</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="157"/>
        <source>device</source>
        <translation>dispositivo</translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="385"/>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="386"/>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="387"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modificare</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="94"/>
        <source>Encoder settings</source>
        <translation>Preferenze di codifica</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="104"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="390"/>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation>Desideri essere informato da un messaggio ogni volta che scegli di esportare?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="106"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="392"/>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="111"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="393"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="116"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="394"/>
        <source>Set default output file:</source>
        <translation>Seleziona il file di uscita predefinito:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="122"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="395"/>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="127"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="396"/>
        <source>Start encoder:</source>
        <translation>Inizia la codifica:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="132"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="397"/>
        <source>Stop encoder:</source>
        <translation>Ferma la codifica:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="361"/>
        <source>Choose output file</source>
        <translation>Scegliere il file di uscita</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="371"/>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation>Di seguito puoi selezionare quale programma Stopmotion dovrebbe utilizzare per codificare il progetto attivo corrente in un file video.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="373"/>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation>Dovresti sempre usare &lt;b&gt;$IMAGEPATH&lt;/b&gt; e &lt;b&gt;$VIDEOFILE&lt;/b&gt; per indicare rispettivamente il percorso dell&apos;immagine e del file video.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="375"/>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="377"/>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation>Esempio con mencoder (da immagini jpeg a video mpeg4):</translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="44"/>
        <source>Input to program:</source>
        <translation>Input del programma:</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="54"/>
        <source>Submit</source>
        <translation>Pubblica</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="60"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="73"/>
        <source>Output from external command</source>
        <translation>Output del comando esterno</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Result</source>
        <translation>Risultato</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <source>Failed!</source>
        <translation>Operazione fallita!</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Successful!</source>
        <translation>Operazione riuscita!</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="32"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framebar/framebar.cpp" line="194"/>
        <source>Frame number: </source>
        <translation>Numero di frame:</translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="114"/>
        <source>Add &amp;sound</source>
        <translation>Aggiungi &amp;suono</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="115"/>
        <source>&amp;Remove Sound</source>
        <translation>&amp;Rimuovi suono</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="116"/>
        <source>Change name</source>
        <translation>Cambia nome</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="117"/>
        <source>Sounds:</source>
        <translation>Suoni:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="120"/>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Aggiungi suono&lt;/h4&gt; &lt;p&gt;Con questo pulsante puoi &lt;em&gt;aggiungere suoni &lt;/em&gt; al frame selezionato.&lt;/p&gt; &lt;p&gt;La riproduzione sonora comincerà quando questo frame è mostrato e durerà fino al completamento.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="128"/>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Rimuovi suono&lt;/h4&gt; &lt;p&gt;Con questo pulsante puoi &lt;em&gt;rimuovere&lt;/em&gt; il suono selezionato da questo frame.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="135"/>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cambia nome&lt;/h4&gt; &lt;p&gt;Con questo pulsante puoi cambiare il nome del suono selezionato. &lt;BR&gt;Il nome assegnato al suono non ha altri effetti se non quelli di rendere il lavoro con l&apos;animazione più semplice.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="143"/>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Suoni&lt;/h4&gt; &lt;p&gt;Questa lista mostra tutti i suoni connessi con il frame attuale.&lt;/p&gt;&lt;p&gt;Questi suoni saranno riprodotti quando il frame è mostrato e continueranno fino al completamento.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation>La cattura è fallita. Questo può succedere se tu tenti di
catturare da un dispositivo non valido. Per favore controlla
le impostazioni di cattura dal menu delle preferenze.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>Devi definire il dispositivo da usare per catturare immagini.
Questo può essere impostato nel menu delle preferenze.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <source>Pre poll command does not exists</source>
        <translation>Il comando di confronto non esiste</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <source>You do not have the given grabber installed on your system</source>
        <translation>Il dispositivo di cattura immagini indicato non è installato sul tuo sistema</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <source>No video device selected in the preferences menu.</source>
        <translation>Nessun dispositivo video selezionato nel menu delle preferenze.</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="324"/>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="325"/>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovere</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="326"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modificare</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="94"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="328"/>
        <source>Import device settings</source>
        <translation>Importa le impostazioni del dispositivo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="103"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="329"/>
        <source>Pre-poll command</source>
        <translation>Comando di confronto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="110"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="330"/>
        <source>Start daemon</source>
        <translation>Avvia demone</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="117"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="331"/>
        <source>Stop daemon</source>
        <translation>Ferma demone</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="59"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="315"/>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation>Di seguito puoi selezionare il programma che Stopmotion dovrebbe usare per acquisire immagini dal dispositivo selezionato.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="61"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="317"/>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation>Dovresti sempre usare &lt;b&gt;$VIDEODEVICE&lt;/b&gt; e &lt;b&gt;$IMAGEFILE&lt;/b&gt; per indicare rispettivamente il dispositivo video e il file di immagine.</translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="105"/>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="87"/>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="89"/>
        <source>&amp;Translation</source>
        <translation>&amp;Traduzione</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="16"/>
        <source>Stopmotion Help Browser</source>
        <translation>Browser di aiuto di Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="40"/>
        <source>Backward</source>
        <translation>Torna indietro</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="50"/>
        <source>Forward</source>
        <translation>Vai avanti</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="86"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="153"/>
        <source>Ready to rumble ;-)</source>
        <translation>Pronto per cominciare :-)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="503"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="504"/>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="590"/>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Apri&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Apri&lt;/em&gt; un progetto di Stopmotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="505"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="506"/>
        <source>Save &amp;As</source>
        <translation>Salva &amp;come</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="509"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="631"/>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Esci&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Esci&lt;/em&gt; dal programma.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="374"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="534"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="510"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="641"/>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Annulla&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Annulla&lt;/em&gt; l&apos;ultima operazione. Puoi premere annulla diverse volte per annullare le operazioni iniziali.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="511"/>
        <source>Re&amp;do</source>
        <translation>&amp;Annulla modifica</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="650"/>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ripristina&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Ripristina&lt;/em&gt; l&apos;ultima operazione. Puoi premere ripristina diverse volte per ripristinare molte operazioni.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="512"/>
        <source>Cu&amp;t</source>
        <translation>T&amp;aglia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="659"/>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Taglia&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Taglia&lt;/em&gt; i frame selezionati e aggiungili agli appunti in modo che tu possa incollarli da un&apos;altra parte.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="513"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="668"/>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Copia&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copia&lt;/em&gt; i frame selezionati negli appunti. Potrai quindi incollarli in un altro posto&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="514"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="677"/>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Incolla&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Incolla&lt;/em&gt; i frame che al momento si trovano negli appunti nel luogo selezionato.&lt;/p&gt; &lt;p&gt;Puoi copiare/tagliare immagini da altri programmi e poi usare questa opzione per incollarle in questa animazione.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="515"/>
        <source>&amp;Go to frame</source>
        <translation>&amp;Vai al frame</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="687"/>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vai al frame&lt;/h4&gt; &lt;p&gt;Questa operazione aprirà un popup in fondo alla zona dove puoi scegliere un frame che desideri raggiungere.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="378"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="563"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modificare</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="395"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="558"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="517"/>
        <source>What&apos;s &amp;This</source>
        <translation>Cos&apos;è &amp;questo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="707"/>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cos&apos;è questo&lt;/h4&gt; &lt;p&gt;L&apos;opzione darà al cursore del mouse la possibilità di aiutarti con informazioni come questa .&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="519"/>
        <source>&amp;About</source>
        <translation>&amp;A proposito di</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="724"/>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;A proposito di&lt;/h4&gt; &lt;p&gt;Questo mostrerà una piccola casella informativa nella quale puoi leggere informazioni generiche come il nome degli sviluppatori che hanno lavorato a questo eccellente programma.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="398"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="518"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="565"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="769"/>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Barra del Frame&lt;/h4&gt; &lt;p&gt;In questa area puoi visualizzare i frame le scene dell&apos;animazione e costruire l&apos;animazione muovendoti intorno.&lt;/p&gt;&lt;p&gt;Puoi cambiare il frame successivo e quello precedente usando i&lt;b&gt;  pulsanti freccia&lt;/b&gt; o &lt;b&gt;x&lt;/b&gt; e &lt;b&gt;z&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="763"/>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Menu degli strumenti&lt;/h4&gt; &lt;p&gt;Questo è il menu degli strumenti dove si trovano la maggior parte dei pulsanti e degli elementi che ti serviranno per lavorare sulle animazioni in stop motion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="756"/>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Menu delle preferenze del frame&lt;/h4&gt; &lt;p&gt;In questo menu puoi determinare le preferenze per il frame/frames selezionati, come &lt;b&gt;sottotitoli&lt;/b&gt;, &lt;b&gt;effetti sonori&lt;/b&gt;, etc.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="750"/>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Vai al menu frame&lt;/h4&gt; &lt;p&gt;Qui puoi specificare il numero del frame e il programma che salterà al frame indicato&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="524"/>
        <source>Go to frame:</source>
        <translation>Vai al frame:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="736"/>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Numero del frame&lt;/h4&gt;&lt;p&gt;Quest&apos;area mostra il numero del frame attualmente selezionato.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="743"/>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vista del frame&lt;/h4&gt;&lt;p&gt; In quest&apos;area puoi vedere il frame selezionato. Puoi anche rirpodurre le animazioni in questa finestra premendo il pulsante di &lt;b&gt;Riproduzione&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="782"/>
        <source>Unsaved changes</source>
        <translation>Non salvare cambiamenti</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="783"/>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>Ci sono cambiamenti non salvati. Vuoi salvarli?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;Yes</source>
        <translation>&amp;Sì</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="507"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="375"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="547"/>
        <source>&amp;Export</source>
        <translation>&amp;Esporta</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="581"/>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nuovo&lt;/h4&gt; &lt;p&gt;Crea un  &lt;em&gt;nuovo&lt;/em&gt; progetto.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="598"/>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Salva&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Salva&lt;/em&gt; l&apos;animazione corrente come progetto Stopmotion. &lt;BR&gt;Se il progetto è stato già salvato verrà automaticamente salvato nel file precedentemente indicato.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="608"/>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Salva come&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Salva&lt;/em&gt; l&apos;animazione corrente come progetto Stopmotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="617"/>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Esporta il progetto corrente come &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;Sarai guidato dall&apos;assistente.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="624"/>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Cinelerra&lt;/h4&gt; &lt;p&gt;Esporta la corrente animazione come progetto&lt;em&gt;Cinelerra&lt;/em&gt;.&lt;/p&gt;Sarai guidato dall&apos;assistente.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="508"/>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="516"/>
        <source>&amp;Configure Stopmotion</source>
        <translation>&amp;Configura Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="376"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="1148"/>
        <source>Open &amp;Recent</source>
        <translation>Apri &amp;recente</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="586"/>
        <source>New project</source>
        <translation>Nuovo progetto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="594"/>
        <source>Open project</source>
        <translation>Apri progetto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="604"/>
        <source>Save project</source>
        <translation>Salva progetto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="613"/>
        <source>Save project As</source>
        <translation>Salva progetto come</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="635"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="646"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="655"/>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="664"/>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="673"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="683"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="692"/>
        <source>Go to frame</source>
        <translation>Vai al frame</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="696"/>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Configura Stopmotion&lt;/h4&gt; &lt;p&gt;Questo aprirà una finestra nella quale puoi &lt;em&gt;configurare&lt;/em&gt; Stopmotion con diversi dispositivi di ingresso e uscita.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="701"/>
        <source>Configure Stopmotion</source>
        <translation>Configura Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="712"/>
        <source>What&apos;s This</source>
        <translation>Cos&apos;è questo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="730"/>
        <source>About</source>
        <translation>A proposito di</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Do&amp;n&apos;t save</source>
        <translation>&amp;Non salva</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="911"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="963"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="912"/>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation>Non è possibile trovare alcun codificatore
per esportare il video. Questo può essere indicato
nel menu delle preferenze. L&apos;esportazione del video non
sarà possibile fin quando non verrà indicato il codificatore da usare.
Vuoi selezionarlo ora?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="948"/>
        <source>Export to video file</source>
        <translation>Esporta al file video</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="964"/>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation>IL codificatore registrato non è valido. Vuoi
controllare le impostazioni nel menu delle preferenze?</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="980"/>
        <source>Export to file</source>
        <translation>Esporta al file</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="716"/>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Aiuto&lt;/h4&gt; &lt;p&gt;Questo pulsante aprirà una finestra di dialogo con il manuale di Stopmotion&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="720"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="522"/>
        <source>Frame number: </source>
        <translation>Numero del frame:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="816"/>
        <source>Choose project file</source>
        <translation>Seleziona un progetto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="884"/>
        <source>Save As</source>
        <translation>Salva come</translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="58"/>
        <source>Choose frames to add</source>
        <translation>Seleziona i frame da aggiungere</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="179"/>
        <source>Removed the selected frame</source>
        <translation>Rimuovi i frame selezionati</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="216"/>
        <location filename="../src/application/modelhandler.cpp" line="227"/>
        <location filename="../src/application/modelhandler.cpp" line="244"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="217"/>
        <source>You do not have Gimp installed on your system</source>
        <translation>Il programma The Gimp non è attualmente installato nel sistema</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="228"/>
        <source>There is no active frame to open</source>
        <translation>Non c&apos;è anclun frame attivo da aprire</translation>
    </message>
    <message>
        <source>The active frame is corrupt</source>
        <translation type="obsolete">Il frame attivo è danneggiato</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="245"/>
        <source>Failed to start Gimp!</source>
        <translation>Impossibile avviare The Gimp!</translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="73"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="119"/>
        <source>Video &amp;Import</source>
        <translation>Importa &amp;video</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="82"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="120"/>
        <source>Video &amp;Export</source>
        <translation>Esporta &amp;video</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="39"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="114"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="43"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="115"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="57"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="116"/>
        <source>Preferences Menu</source>
        <translation>Menu delle preferenze</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="91"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="118"/>
        <source>Video &amp;Device</source>
        <translation>Dispositivo &amp;video</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="192"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="207"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="196"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="204"/>
        <source>Fatal</source>
        <translation>Errore fatale</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="120"/>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">vgrabbj VGA singleshot</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="278"/>
        <source>vgrabbj VGA daemon</source>
        <translation>demone vgrabbj VGA</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="280"/>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation>Avvia vgrabbj come demone. Molto veloce.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="418"/>
        <source>Question</source>
        <translation>Chiedi</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="271"/>
        <source>The simplest setting. Fairly slow</source>
        <translation>L&apos;impostazione più semplice. Piuttosto lenta</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="101"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="104"/>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="107"/>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="110"/>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="113"/>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="116"/>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="269"/>
        <source>vgrabbj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="288"/>
        <source>uvccapture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="290"/>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="324"/>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation>Esporta da immagini jpeg a video mpeg1</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="368"/>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished">Stopmotion non ha potuto aprirsi. Sembra che sia già aperto.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="411"/>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation>Esiste una nuova versione del file di preferenze con maggiori caratteristiche predefinite.
Vuoi usarla? (Le vecchie preferenze saranno salvate in ~/.stopmotion/preferences.xml.OLD)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="333"/>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation>Esporta da immagini jpeg a video mpeg2</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="351"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="359"/>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation>Esporta da immagini jpeg a video mpeg4</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="306"/>
        <source>dvgrab</source>
        <translation>dvgrab</translation>
    </message>
    <message>
        <source>Grabbing from DV-cam. (EXPERIMENTAL)</source>
        <translation type="obsolete">Cattura da una DV-cam. (SPERIMENTALE)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="297"/>
        <source>videodog singleshot</source>
        <translation>videodog singleshot</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="299"/>
        <source>Videodog.</source>
        <translation>Videodog.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="308"/>
        <source>Grabbing from DV-cam.</source>
        <translation>Cattura da DV-cam.</translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <location filename="../src/application/runanimationhandler.cpp" line="90"/>
        <source>Running animation</source>
        <translation>Riproduci l&apos;animazione</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Sounds (*.ogg)</source>
        <translation>Suoni (*.ogg)</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="70"/>
        <source>Sound name</source>
        <translation>Nome del suono</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="71"/>
        <source>Enter the name of the sound:</source>
        <translation>Inserisci il nome del suono:</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Choose sound file</source>
        <translation>Scegli il file del suono</translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="223"/>
        <source>FPS chooser</source>
        <translation>Scegli FPS</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="301"/>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Seleziona FPS&lt;/h4&gt; &lt;p&gt;Cambiando il valore puoi determinare a quale velocità l&apos;animazione contenuta nel &lt;b&gt;visualizzatore&lt;/b&gt; dovrebbe andare.&lt;/p&gt; &lt;p&gt;Per avviare l&apos;animazione premi &lt;b&gt;Avvia animazione&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="224"/>
        <source>Number of images:</source>
        <translation>Numero di immagini:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="227"/>
        <source>Mix</source>
        <translation>Mix</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="228"/>
        <source>Diff</source>
        <translation>Differenza</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="229"/>
        <source>Playback</source>
        <translation>Playback</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="234"/>
        <source>Per second</source>
        <translation type="unfinished">un secondo</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="235"/>
        <source>Per minute</source>
        <translation type="unfinished">un minuto</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="236"/>
        <source>Per hour</source>
        <translation type="unfinished">un&apos;ora</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="241"/>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Aggiungi frame (CTRL+F)&lt;/h4&gt; &lt;p&gt;Clicca su questo pulsante per &lt;em&gt;aggiungere&lt;/em&gt; frame alla animazione &lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="248"/>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Rimuovi selezione (Cancella)&lt;/h4&gt; &lt;p&gt;Premendo questo pulsante &lt;em&gt;rimuovi&lt;/em&gt; i frame selezionati dall&apos;animazione.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="255"/>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nuova scena (CTRL+E)&lt;/h4&gt; &lt;p&gt;Premi questo pulsante per &lt;em&gt;creare&lt;/em&gt; una &lt;em&gt;scena&lt;/em&gt; nuova per l&apos;animazione.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="262"/>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Rimuovi la scena(CTRL+E)&lt;/h4&gt; &lt;p&gt;Premi questo pulsante per &lt;em&gt;rimuovere&lt;/em&gt; la scena selezionata dall&apos;animazione.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="269"/>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Verifica on/off della camera (C)&lt;/h4&gt; &lt;p&gt;Premi questo pulsante per verificare on/off della camera&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="282"/>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Cattura frame (Barra spaziatrice)&lt;/h4&gt; &lt;p&gt;Premi questo pulsante per &lt;em&gt;catturare&lt;/em&gt; un frame dalla camera e inserirlo nell&apos;animazione&lt;/p&gt; &lt;p&gt;Questo può essere fatto anche premendo la &lt;b&gt;Barra spaziatrice&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="290"/>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Numero di immagini&lt;/h4&gt; &lt;p&gt;Cambiando questo valore nella barra di selezione puoi specificare di quante immagini riavvolgere l&apos;animazione che dovrebbe essere mixata con la camere o con la modalità playback: quante immagini avviare .&lt;/p&gt; &lt;p&gt;Mixando le immagini precedenti nella camera puoi pià facilmente vedere come lo scatto successivo starà in relazione alle altre, e quindi produrre una animazione in stop motion più fluida!&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="311"/>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Riprodurre animazione (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="314"/>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Fermare l&apos;animazione (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="317"/>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Frame precedente (J, Sinistra)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="320"/>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Frame successivo (L, Destra)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="323"/>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Scena precedente (I)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="326"/>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Scena successiva (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="330"/>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Loop dell&apos;animazione (CTRL+L)&lt;/h4&gt; &lt;p&gt;Con questo pulsante puoi indicare se desideri che l&apos;animazione venga riprodotta fino alla fine, oppure indefinitamente.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Notice</source>
        <translation>Note</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation>Playback funziona attualmente solo quando la cattura è 
impostata come demone. Vai al menu delle preferenze (CTRL+P)
per selezionare la cattura come demone.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="230"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Pr sec</source>
        <translation type="obsolete">Pr sec</translation>
    </message>
    <message>
        <source>Pr min</source>
        <translation type="obsolete">Pr min</translation>
    </message>
    <message>
        <source>Pr hr</source>
        <translation type="obsolete">Pr hr</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="275"/>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Avvia The Gimp&lt;/h4&gt; &lt;p&gt; Click su questo tasto per aprire il frame corrente con The Gimp&lt;/p&gt; &lt;p&gt;Ricorda che puoi anche trascinare le immagini dalla barra dei frame sulla finestra di The Gimp&lt;/p&gt;</translation>
    </message>
</context>
</TS>
